zone

package
v0.0.0-...-0c8abf8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 14, 2021 License: AGPL-3.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

const (
	// Label holds the string label denoting the zone type in the database.
	Label = "zone"
	// FieldID holds the string denoting the id field in the database.
	FieldID = "id"
	// Table holds the table name of the zone in the database.
	Table = "zones"
)

Variables

var Columns = []string{
	FieldID,
}

Columns holds all SQL columns for zone fields.

Functions

func And

func And(predicates ...predicate.Zone) predicate.Zone

And groups predicates with the AND operator between them.

func ID

func ID(id int) predicate.Zone

ID filters vertices based on their ID field.

func IDEQ

func IDEQ(id int) predicate.Zone

IDEQ applies the EQ predicate on the ID field.

func IDGT

func IDGT(id int) predicate.Zone

IDGT applies the GT predicate on the ID field.

func IDGTE

func IDGTE(id int) predicate.Zone

IDGTE applies the GTE predicate on the ID field.

func IDIn

func IDIn(ids ...int) predicate.Zone

IDIn applies the In predicate on the ID field.

func IDLT

func IDLT(id int) predicate.Zone

IDLT applies the LT predicate on the ID field.

func IDLTE

func IDLTE(id int) predicate.Zone

IDLTE applies the LTE predicate on the ID field.

func IDNEQ

func IDNEQ(id int) predicate.Zone

IDNEQ applies the NEQ predicate on the ID field.

func IDNotIn

func IDNotIn(ids ...int) predicate.Zone

IDNotIn applies the NotIn predicate on the ID field.

func Not

Not applies the not operator on the given predicate.

func Or

func Or(predicates ...predicate.Zone) predicate.Zone

Or groups predicates with the OR operator between them.

func ValidColumn

func ValidColumn(column string) bool

ValidColumn reports if the column name is valid (part of the table columns).

Types

This section is empty.

Jump to