Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.Zone) predicate.Zone
- func ID(id int) predicate.Zone
- func IDEQ(id int) predicate.Zone
- func IDGT(id int) predicate.Zone
- func IDGTE(id int) predicate.Zone
- func IDIn(ids ...int) predicate.Zone
- func IDLT(id int) predicate.Zone
- func IDLTE(id int) predicate.Zone
- func IDNEQ(id int) predicate.Zone
- func IDNotIn(ids ...int) predicate.Zone
- func Not(p predicate.Zone) predicate.Zone
- func Or(predicates ...predicate.Zone) predicate.Zone
- func ValidColumn(column string) bool
Constants ¶
const ( // Label holds the string label denoting the zone type in the database. Label = "zone" // FieldID holds the string denoting the id field in the database. FieldID = "id" // Table holds the table name of the zone in the database. Table = "zones" )
Variables ¶
var Columns = []string{ FieldID, }
Columns holds all SQL columns for zone fields.
Functions ¶
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.